#[repr(u8)]pub enum Tot {
NOTRNPS = 0,
BTS_TRNPS = 1,
BYTS_BTS_TRNPS = 2,
BYTS_TRNPS = 3,
}Variants
NOTRNPS = 0
No transposition
BTS_TRNPS = 1
Bits in bytes are transposed, but bytes are not transposed.
BYTS_BTS_TRNPS = 2
Both bits in bytes and bytes are transposed.
BYTS_TRNPS = 3
Only bytes are transposed, no bits in a byte are transposed.
Implementations